@@ -91,17 +91,21 @@ vvm_util_create_deactivate_sms (const char *carrier_prefix,
   if (g_strcmp0 (vvm_type, "cvvm") == 0)
     return g_strdup_printf ("%s%s", DEACTIVATE_SMS_PREFIX, CCVM_SUFFIX);
   else if (g_strcmp0 (vvm_type, "otmp") == 0)
-    //TODO: Fix this for other carriers
-    // Refer to "OMTP_VVM_Specification v1.3, Section 2.9.2.3
-    // It should look similar to: "Deactivate:pv=<value>;ct=<value>;pt=<value>;<Clientprefix>:"
-    // message = g_strdup("Deactivate:pv=<value>;ct=<value>;pt=<value>;<Clientprefix>:");
-    // message = g_strdup("%s%s%s;%s<value>;%s<value>;<Clientprefix>:", DEACTIVATE_SMS_PREFIX, PROTOCOL_VERSION_PREFIX, PROTOCOL_VERSION_1_3, CLIENT_TYPE_PREFIX, TERMINAL_DESTINATION_PORT_NUMBER_PREFIX);
-    // pv should be "13", I do not know the values for "ct" and "pt"
-    // I think if <Clientprefix> is default (//VVM), it can be "Deactivate:pv=<value>;ct=<value>;pt=<value>"
-    // message = g_strdup("Deactivate:pv=<value>;ct=<value>;pt=<value>");
-    // or with vvmutil.h
-    // message = g_strdup("%s%s%s;%s<value>;%s<value>", DEACTIVATE_SMS_PREFIX, PROTOCOL_VERSION_PREFIX, PROTOCOL_VERSION_1_3, CLIENT_TYPE_PREFIX, TERMINAL_DESTINATION_PORT_NUMBER_PREFIX);
-    DBG ("I do not know how to unsubscribe from an OMTP VVM service!");
+    /*
+     * Refer to "OMTP_VVM_Specification v1.3, Section 2.9.2.3
+     * It should look similar to: "Deactivate:pv=<value>;ct=<value>;pt=<value>;<Clientprefix>:"
+     * message = g_strdup("Deactivate:pv=<value>;ct=<value>;pt=<value>;<Clientprefix>:");
+     * message = g_strdup("%s%s%s;%s<value>;%s<value>;<Clientprefix>:", DEACTIVATE_SMS_PREFIX, PROTOCOL_VERSION_PREFIX, PROTOCOL_VERSION_1_3, CLIENT_TYPE_PREFIX, TERMINAL_DESTINATION_PORT_NUMBER_PREFIX);
+     * pv should be "13", I do not know the values for "ct" and "pt"
+     * I think if <Clientprefix> is default (//VVM), it can be "Deactivate:pv=<value>;ct=<value>;pt=<value>"
+     * message = g_strdup("Deactivate:pv=<value>;ct=<value>;pt=<value>");
+     * or with vvmutil.h
+     * message = g_strdup("%s%s%s;%s<value>;%s<value>", DEACTIVATE_SMS_PREFIX, PROTOCOL_VERSION_PREFIX, PROTOCOL_VERSION_1_3, CLIENT_TYPE_PREFIX, TERMINAL_DESTINATION_PORT_NUMBER_PREFIX);
+     * In looking at Android: https://cs.android.com/android/platform/superproject/+/master:packages/apps/Dialer/java/com/android/voicemail/impl/sms/OmtpMessageSender.java
+     * They did not implement how to activate nor deactivate OMTP.
+     * Therefore, I doubt any carrier actually implements this.
+     */
+    g_warning ("I do not know how to unsubscribe from an OMTP VVM service!");
   else if (g_strcmp0 (vvm_type, "AT&TUSAProprietary") == 0)
     g_critical ("I do not know how to unsubscribe from AT&T USA!");
   else if (g_strcmp0 (vvm_type, "FreeMobileProprietary") == 0)
@@ -109,7 +113,7 @@ vvm_util_create_deactivate_sms (const char *carrier_prefix,
   else if (g_strcmp0 (vvm_type, "ios") == 0)
     g_critical ("I do not know how to unsubscribe from ios!");
   else if (g_strcmp0 (vvm_type, "vvm3") == 0)
-    g_critical ("There is no way to unsubscribe from vvm3!");
+    g_warning ("There is no way to unsubscribe from vvm3!");
   else
     g_critical ("Unknown type of VVM service.");
   return NULL;
@@ -122,24 +126,31 @@ vvm_util_create_activate_sms (const char *carrier_prefix,
   if (g_strcmp0 (vvm_type, "cvvm") == 0)
     return g_strdup_printf ("%s%s", ACTIVATE_SMS_PREFIX, CCVM_SUFFIX);
   else if (g_strcmp0 (vvm_type, "otmp") == 0)
-    //TODO: Fix this for other carriers
-    // Refer to "OMTP_VVM_Specification v1.3, Section 2.9.2.2
-    // It should look similar to: "Activate:pv=<value>;ct=<value>;pt=<value>;<Clientprefix>:"
-    // message = g_strdup("Activate:pv=<value>;ct=<value>;pt=<value>;<Clientprefix>:");
-    // or with vvmutil.h
-    // message = g_strdup("%s%s%s;%s<value>;%s<value>;<Clientprefix>:", ACTIVATE_SMS_PREFIX, PROTOCOL_VERSION_PREFIX, PROTOCOL_VERSION_1_3, CLIENT_TYPE_PREFIX, TERMINAL_DESTINATION_PORT_NUMBER_PREFIX);
-    // pv should be "13", I do not know the values for "ct" and "pt"
-    // I think if <Clientprefix> is default (//VVM), it can be:"Activate:pv=<value>;ct=<value>;pt=<value>"
-    // message = g_strdup("Activate:pv=<value>;ct=<value>;pt=<value>");
-    // or with vvmutil.h
-    // message = g_strdup("%s%s%s;%s<value>;%s<value>", ACTIVATE_SMS_PREFIX, PROTOCOL_VERSION_PREFIX, PROTOCOL_VERSION_1_3, CLIENT_TYPE_PREFIX, TERMINAL_DESTINATION_PORT_NUMBER_PREFIX);
-    DBG ("I do not know how to subscribe to an OMTP VVM service!");
+    /* Refer to "OMTP_VVM_Specification v1.3, Section 2.9.2.2
+     * It should look similar to: "Activate:pv=<value>;ct=<value>;pt=<value>;<Clientprefix>:"
+     * message = g_strdup("Activate:pv=<value>;ct=<value>;pt=<value>;<Clientprefix>:");
+     * or with vvmutil.h
+     * message = g_strdup("%s%s%s;%s<value>;%s<value>;<Clientprefix>:", ACTIVATE_SMS_PREFIX, PROTOCOL_VERSION_PREFIX, PROTOCOL_VERSION_1_3, CLIENT_TYPE_PREFIX, TERMINAL_DESTINATION_PORT_NUMBER_PREFIX);
+     * pv should be "13", I do not know the values for "ct" and "pt"
+     * I think if <Clientprefix> is default (//VVM), it can be:"Activate:pv=<value>;ct=<value>;pt=<value>"
+     * message = g_strdup("Activate:pv=<value>;ct=<value>;pt=<value>");
+     * or with vvmutil.h
+     * message = g_strdup("%s%s%s;%s<value>;%s<value>", ACTIVATE_SMS_PREFIX, PROTOCOL_VERSION_PREFIX, PROTOCOL_VERSION_1_3, CLIENT_TYPE_PREFIX, TERMINAL_DESTINATION_PORT_NUMBER_PREFIX);
+     * In looking at Android: https://cs.android.com/android/platform/superproject/+/master:packages/apps/Dialer/java/com/android/voicemail/impl/sms/OmtpMessageSender.java
+     * They did not implement how to activate nor deactivate OMTP.
+     * Therefore, I doubt any carrier actually implements this.
+     */
+    g_warning ("I do not know how to subscribe to an OMTP VVM service!");
   else if (g_strcmp0 (vvm_type, "AT&TUSAProprietary") == 0)
     return vvm_util_create_att_usa_status_sms (carrier_prefix);
   else if (g_strcmp0 (vvm_type, "FreeMobileProprietary") == 0)
     return vvm_util_create_ios_status_sms (carrier_prefix);
   else if (g_strcmp0 (vvm_type, "ios") == 0)
     return vvm_util_create_ios_status_sms (carrier_prefix);
+  /* There is no specific activate request for vvm3, you just send a
+   * status message. If it isn't activated, then there will be a place
+   * later it activates
+   */
   else if (g_strcmp0 (vvm_type, "vvm3") == 0)
     return g_strdup_printf ("STATUS");
   else
@@ -155,18 +166,21 @@ vvm_util_create_status_sms (const char *carrier_prefix,
   if (g_strcmp0 (vvm_type, "cvvm") == 0)
     return g_strdup_printf ("%s%s", STATUS_SMS_PREFIX, CCVM_SUFFIX);
   else if (g_strcmp0 (vvm_type, "otmp") == 0)
-    //TODO: Fix this for other carriers
-    // Refer to "OMTP_VVM_Specification v1.3, Section 2.9.2.1
-    // The message should look similar to "STATUS:pv=<value>;ct=<value>;pt=<value>;<Clientprefix>:"
-    // message = g_strdup("STATUS:pv=<value>;ct=<value>;pt=<value>;<Clientprefix>:");
-    // or with vvmutil.h
-    // message = g_strdup("%s%s%s;%s<value>;%s<value>;<Clientprefix>:", STATUS_SMS_PREFIX, PROTOCOL_VERSION_PREFIX, PROTOCOL_VERSION_1_3, CLIENT_TYPE_PREFIX, TERMINAL_DESTINATION_PORT_NUMBER_PREFIX);
-    // pv should be "13", I do not know the values for "ct" and "pt"
-    // I think if <Clientprefix> is default (//VVM), it can be: "STATUS:pv=<value>;ct=<value>;pt=<value>"
-    // message = g_strdup("STATUS:pv=<value>;ct=<value>;pt=<value>");
-    // or with vvmutil.h
-    // message = g_strdup("%s%s%s;%s<value>;%s<value>;", STATUS_SMS_PREFIX, PROTOCOL_VERSION_PREFIX, PROTOCOL_VERSION_1_3, CLIENT_TYPE_PREFIX, TERMINAL_DESTINATION_PORT_NUMBER_PREFIX);
-    DBG ("I do not know how check the status of an OMTP VVM service!");
+    /* Refer to "OMTP_VVM_Specification v1.3, Section 2.9.2.1
+     * The message should look similar to "STATUS:pv=<value>;ct=<value>;pt=<value>;<Clientprefix>:"
+     * message = g_strdup("STATUS:pv=<value>;ct=<value>;pt=<value>;<Clientprefix>:");
+     * or with vvmutil.h
+     * message = g_strdup("%s%s%s;%s<value>;%s<value>;<Clientprefix>:", STATUS_SMS_PREFIX, PROTOCOL_VERSION_PREFIX, PROTOCOL_VERSION_1_3, CLIENT_TYPE_PREFIX, TERMINAL_DESTINATION_PORT_NUMBER_PREFIX);
+     * pv should be "13", I do not know the values for "ct" and "pt"
+     * I think if <Clientprefix> is default (//VVM), it can be: "STATUS:pv=<value>;ct=<value>;pt=<value>"
+     * message = g_strdup("STATUS:pv=<value>;ct=<value>;pt=<value>");
+     * or with vvmutil.h
+     * message = g_strdup("%s%s%s;%s<value>;%s<value>;", STATUS_SMS_PREFIX, PROTOCOL_VERSION_PREFIX, PROTOCOL_VERSION_1_3, CLIENT_TYPE_PREFIX, TERMINAL_DESTINATION_PORT_NUMBER_PREFIX);
+     * In looking at Android: https://cs.android.com/android/platform/superproject/+/master:packages/apps/Dialer/java/com/android/voicemail/impl/sms/OmtpMessageSender.java
+     * They did not implement how to check the status of OMTP.
+     * Therefore, I doubt any carrier actually implements this.
+     */
+    g_warning ("I do not know how check the status of an OMTP VVM service!");
   else if (g_strcmp0 (vvm_type, "AT&TUSAProprietary") == 0)
     return vvm_util_create_att_usa_status_sms (carrier_prefix);
   else if (g_strcmp0 (vvm_type, "FreeMobileProprietary") == 0)
@@ -861,7 +875,7 @@ vvm_util_decode_vvm_single_email_attachment (const char *attachment,
           else if (found_attachment == FALSE)
             {
               attachment_line = i;
-              DBG ("Attachment contents on line: %d, length %lu",
+              DBG ("Attachment contents on line: %d, length %" G_GSIZE_FORMAT,
                    attachment_line, strlen (lines[i]));
               found_attachment = TRUE;
             }
@@ -890,8 +904,20 @@ vvm_util_decode_vvm_single_email_attachment (const char *attachment,
       }
   if (filename == NULL)
     {
-      g_critical ("Could not find a file name.");
-      return g_strdup ("NONE");
+      if (strstr (contenttype, "audio/amr"))
+        {
+           filename = g_strdup ("voicemail.amr");
+           DBG ("filename: %s", filename);
+        }
+      else if (strstr (contenttype, "audio/wav"))
+        {
+           filename = g_strdup ("voicemail.wav");
+           DBG ("filename: %s", filename);
+        }
+      else {
+           g_critical ("Could not find a file name.");
+           return g_strdup ("NONE");
+        }
     }
 
   DBG ("Folder Path: %s", folderpath);
@@ -920,6 +946,7 @@ vvm_util_decode_vvm_single_email_attachment (const char *attachment,
         decoded = g_string_append (decoded, lines[i]);
     }
   string_to_decode = g_string_free (decoded, FALSE);
+  //DBG("decoded message: %s", string_to_decode);
   if (string_to_decode == NULL)
     {
       g_critical ("Error reconstructing attachment!");
